@@ -2,7 +2,7 @@
  * capture.c: capture data from stdout and stderr
  *
  *
- * Copyright (C) 2007-2008 Michael Brunner <mibru@gmx.de>
+ * Copyright (C) 2007-2009 Michael Brunner <mibru@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,6 +16,8 @@
  * General Public License for more details.
  */
 
+#include "logapp.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -31,7 +33,6 @@
 #include <time.h>
 #include <pthread.h>
 
-#include "logapp.h"
 #include "configuration.h"
 #include "logfile.h"
 #include "capture.h"
@@ -40,10 +41,12 @@ int handle_cbstream(pipe_t* pipe);
 
 void reset_console(void)
 {
+	int err = 0;;
+
 	if (!config.dumbterm) {
-		write(app.pstdout->cfhno, app.pstdout->escreset,
+		err = write(app.pstdout->cfhno, app.pstdout->escreset,
 		      app.pstdout->escresetlen);
-		write(app.pstderr->cfhno, app.pstderr->escreset,
+		err = write(app.pstderr->cfhno, app.pstderr->escreset,
 		      app.pstderr->escresetlen);
 	}
 
@@ -52,6 +55,10 @@ void reset_console(void)
 
 	tcdrain(STDOUT_FILENO);
 	tcdrain(STDERR_FILENO);
+
+	if (err == -1) {
+		warning("Problem reseting console...");
+	}
 }
 
 static int recalc_cliplen(pipe_t *pipe)
@@ -97,8 +104,7 @@ int print_stream(pipe_t *pipe)
 	if (!config.dumbterm) {
 		/* Check for regular expression match */
 		if (pipe->regexp) {
-			if (!regexec(&pipe->preg, pipe->buf, pipe->bfill,
-				     NULL, 0)) {
+			if (!(regexec(&pipe->preg, pipe->buf, 0, NULL, 0))) {
 				regmatch = 1;
 			}
 		}
@@ -171,7 +177,8 @@ int print_stream(pipe_t *pipe)
 		}
 	}
 
-	write(pipe->cfhno, buf, ccount + esclength);
+	if (write(pipe->cfhno, buf, ccount + esclength) == -1)
+		return -1;
 
 	if (regmatch && !config.dumbterm) {
 		/* Restore \n */
@@ -295,7 +302,7 @@ int read_pipe(pipe_t *pipe)
 			pipe->recalclen = 1;
 
 		if (pipe->buf[pipe->bfill] == '\n'
-		    || ( i + pipe->bfill > pipe->blen)
+		    || ( i + pipe->bfill >= pipe->blen)
 		    || ((pipe->buf[pipe->bfill] == 27) && pipe->detectescape)
 		    ) {
 			if ((pipe->buf[pipe->bfill] == '\n') && (i > 0)) {
@@ -315,7 +322,7 @@ int read_pipe(pipe_t *pipe)
 				/* Switch to charbased stream handling as we
 				 * just detected an escape sequence */
 				pipe->switchtocbmode = 1;
-			} else if ( i + pipe->bfill > pipe->blen) {
+			} else if ( i + pipe->bfill >= pipe->blen) {
 				pipe->bfill++;
 			}
 
@@ -326,6 +333,9 @@ int read_pipe(pipe_t *pipe)
 				pipe->bfill--;
 			}
 
+			/* NULL terminate string, as needed for regexec */
+			pipe->buf[pipe->bfill] = '\0';
+
 			return(pipe->bfill);
 		};
 		if (pipe->bfill < pipe->blen)
@@ -344,7 +354,7 @@ int prepare_buffer(pipe_t* pipe)
 		if (!(pipe->buf = (char*)malloc(len))) {
 			error_outofmemory();
 			error("trying to allocate %d byte "
-			      "%s buffer\n", pipe->blen + 1, pipe->name);
+			      "%s buffer\n", len, pipe->name);
 			return -1;
 		}
 
@@ -450,7 +460,11 @@ int handle_cbstream(pipe_t* pipe)
 		}
 
 		/* Write to console */
-		write(pipe->cfhno, pipe->buf, pipe->bfill);
+		if (write(pipe->cfhno, pipe->buf, pipe->bfill) == -1) {
+			error("Problem writing data to screen for %s\n",
+			      pipe->name);
+			return -1;
+		}
 
 		/* Write to logfile */
 		if (logfile_write(app.logfile, pipe)) {
@@ -468,7 +482,12 @@ int handle_cbstream(pipe_t* pipe)
 				pipe->bfill = 1;
 
 				/* Write to console */
-				write(pipe->cfhno, pipe->buf, pipe->bfill);
+				if (write(pipe->cfhno, pipe->buf, pipe->bfill)
+				    == -1) {
+					error("Problem writing data to screen "
+					      "for %s\n", pipe->name);
+					return -1;
+		}
 
 				/* Write to logfile */
 				if (logfile_write(app.logfile, pipe)) {
@@ -490,13 +509,13 @@ int handle_lbstream(pipe_t* pipe)
 	if ((pipe->state = read_pipe(pipe)) > 0) {
 		int clearbuf;
 
-		if ((clearbuf = print_stream(pipe)) < 0) {
-			error("error printing %s output\n", pipe->name);
+		if (logfile_write(app.logfile, pipe)) {
+			error("error writing logfile\n");
 			return -1;
 		}
 
-		if (logfile_write(app.logfile, pipe)) {
-			error("error writing logfile\n");
+		if ((clearbuf = print_stream(pipe)) < 0) {
+			error("error printing %s output\n", pipe->name);
 			return -1;
 		}
 
