@@ -2,7 +2,7 @@
  * configuration.c: logapp configuration handling
  *
  *
- * Copyright (C) 2007-2008 Michael Brunner <mibru@gmx.de>
+ * Copyright (C) 2007-2009 Michael Brunner <mibru@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,6 +16,8 @@
  * General Public License for more details.
  */
 
+#include "logapp.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -573,14 +575,14 @@ static int fixup_pipe(pipe_t *pipe)
 	pipe->esccolorlen += pipe->escresetlen;
 
 	if (pipe->fgcol >= 0) {
-		sprintf(pipe->esccolor + pipe->esccolorlen, "\033[3%dm",
+		snprintf(pipe->esccolor + pipe->esccolorlen, 6, "\033[3%dm",
 			pipe->fgcol);
 		pipe->esccolorlen += 5;
 	}
 
 	if (pipe->regbgcol >= 0) {
 		pipe->bgesccolor = pipe->esccolor + pipe->esccolorlen + 3;
-		sprintf(pipe->esccolor + pipe->esccolorlen, "\033[4%dm",
+		snprintf(pipe->esccolor + pipe->esccolorlen, 6, "\033[4%dm",
 			pipe->bgcol); 
 		pipe->esccolorlen += 5;
 	} else {
@@ -588,7 +590,7 @@ static int fixup_pipe(pipe_t *pipe)
 	}
 	
 	if (pipe->bold) {
-		sprintf(pipe->esccolor + pipe->esccolorlen, "\033[1m");
+		snprintf(pipe->esccolor + pipe->esccolorlen, 5, "\033[1m");
 		pipe->esccolorlen += 4;
 	}
 
