@@ -19,8 +19,6 @@
 #ifndef __LOGAPP_H__
 #define __LOGAPP_H__
 
-#define VERSION		"0.12"
-#define EXECUTABLE	"logapp"
 #define AUTHOR		"Michael Brunner <mibru@gmx.de>"
 
 typedef enum { MESSAGE, WARNING, ERROR } t_printtype;
@@ -32,7 +30,9 @@ typedef enum { MESSAGE, WARNING, ERROR } t_printtype;
 void print(t_printtype type, const char *format,...);
 void error_outofmemory(void);
 
-#define CONFIG_SUPPORT_PTY	1
-#define CONFIG_USE_THREADS	1
+#if (CONFIG_USE_THREADS == 1)
+/* Let the system take care of making errno thread safe. */
+#define _REENTRANT
+#endif
 
 #endif /* __LOGAPP_H__ */
