@@ -2,7 +2,7 @@
  * main.c: logapp main file
  *
  *
- * Copyright (C) 2007-2008 Michael Brunner <mibru@gmx.de>
+ * Copyright (C) 2007-2009 Michael Brunner <mibru@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,6 +16,7 @@
  * General Public License for more details.
  */
 
+#include "logapp.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -33,7 +34,6 @@
 #include <signal.h>
 #include <pty.h>
 
-#include "logapp.h"
 #include "configuration.h"
 #include "logfile.h"
 #include "capture.h"
@@ -106,7 +106,7 @@ void usage(void)
 	char linebuf[LINELENGTH + 1];
 
 	message("%s %s\n\n", EXECUTABLE, VERSION);
-	message("Usage: %s [OPTIONS] APPLICATION...\n", EXECUTABLE);
+	message("Usage: %s [OPTION]... APPLICATION...\n", EXECUTABLE);
 
 	/* omit rest of the usage instructions if it has not been requested
 	 * with the --help parameter */
@@ -122,23 +122,24 @@ void usage(void)
 			continue;
 		}
 
-		sprintf(linebuf, "  ");
+		snprintf(linebuf, 3, "  ");
 		if (arglist[i].shrt) {
-			sprintf(&linebuf[2], "-%c ", arglist[i].shrt);
+			snprintf(&linebuf[2], 4, "-%c ", arglist[i].shrt);
 		} else
-			sprintf(&linebuf[2], "    ");
+			snprintf(&linebuf[2], 4, "    ");
 
 		offset = 5;
 		if (arglist[i].lng)
-			offset += sprintf(&linebuf[5], "--%s", arglist[i].lng);
+			offset += snprintf(&linebuf[5], LINELENGTH-5,
+					  "--%s", arglist[i].lng);
 		else
-			offset += sprintf(&linebuf[5], "    ");
+			offset += snprintf(&linebuf[5], 5, "    ");
 
 		if (arglist[i].parm)
-			offset += sprintf(&linebuf[offset], "=%s ",
-					  arglist[i].parm);
+			offset += snprintf(&linebuf[offset], LINELENGTH-offset,
+					  "=%s ", arglist[i].parm);
 
-		/* Not checking return values of sprintf above, but be sure
+		/* Not checking return values of snprintf above, but be sure
 		 * that offset didn't get smaller before continuing */
 		if (offset < 5)
 			exit(-1);
@@ -185,9 +186,11 @@ void usage(void)
 
 void version(void) {
 	message("%s %s\n", EXECUTABLE, VERSION);
-	message("Build date: %s %s\n\n", __DATE__, __TIME__);
+	message("Build date: %s %s\n", __DATE__, __TIME__);
+	if (strlen(SVN_REVISION))
+		message("SVN revision: %s\n\n", SVN_REVISION);
 
-	message("Compiletime configuration:\n");
+	message("\nCompiletime configuration:\n");
 	message("  PTY support %s\n", CONFIG_SUPPORT_PTY?"enabled":"disabled");
 	message("  Thread usage %s\n\n",
 		CONFIG_USE_THREADS?"enabled":"disabled");
